==> mayi-business_component-1.1.0.tgz: package/src/utils/ossDirectTransmission.js <==
import { getOssConfig } from "../api/testOss";

let stopUp = false;//中断上传  临时方法
let xhr = null;

function random_string(len) {
  len = len || 32;
  var chars = "ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678";
  var maxPos = chars.length;
  var pwd = "";
  for (let i = 0; i < len; i++) {
    pwd += chars.charAt(Math.floor(Math.random() * maxPos));
  }
  return pwd;
};
function get_suffix(filename) {
  let pos = filename.lastIndexOf(".");
  let suffix = "";
  if (pos != -1) {
    suffix = filename.substring(pos);
  }
  return suffix;
}
function getFileType(name) {
  if (!name) return false;
  var imgType = ["gif", "jpeg", "jpg", "bmp", "png"];
  var videoType = ["avi", "wmv", "mkv", "mp4", "mov", "rm", "3gp", "flv", "mpg", "rmvb"];
  if (RegExp("\.(" + imgType.join("|") + ")$", "i").test(name.toLowerCase())) {
    return 'image';
  } else if (RegExp("\.(" + videoType.join("|") + ")$", "i").test(name.toLowerCase())) {
    return 'video';
  } else {
    return false;
  }
}
function progressFunction(event, index, progress) {
  console.log(stopUp, '---------stopUp')
  if (stopUp) {
    xhr.abort();
  }
  // 设置进度显示
  if (event.lengthComputable) {
    var percent = Math.floor((event.loaded / event.total) * 100);
    if (percent > 100) {
      percent = 100;
    }
    uploadImgArr[index] = {
      type: 'conduct',
      res: {},
      progress: percent,
    }
    let newArr = JSON.parse(JSON.stringify(uploadImgArr));

    progress(newArr, false);
  }
}
/**
 * callback--是否上传成功及成功url
 * type:again：开始上传/success：成功  fileType:文件类型
 * progress--上传中进度
 */
let uploadImgArr = [];
let allUploadImgArr = [];
let uploadImgLength = 0;


/**
 * 
 * @param {*} file --入参   原生input 类型  e.target.files  不是数组  伪数组(对象类型key为index)
 * @param {*} callback--一组上传全部成功回调  返回值有：类型(again:开始上传、success：上传成功)、文件相对地址及绝对地址、进度默认100
 * @param {*} progress --一组上传中的回调  返回值有：类型(conduct:上传成功)、实时进度
 * 
 * TODO:客户端使用时可将callback回调参数与每组合并成已上传的总数组，progress回调可作为当前组的进度展示
 */
export function _ossDT(file, callback, progress) {
  stopUp = false
  uploadImgArr = [];
  uploadImgLength = 0;
  let fileList = file;
  let pro = new Promise((resolve, rej) => {
    // 判断签名有没有过期
    var res = JSON.parse(localStorage.getItem("sign"));
    var timestamp = Date.parse(new Date()) / 1000;
    if (res && res.expire - 3 > timestamp) {
      resolve(res);
    } else {
      let arr = Object.values(fileList).map(item => {
        return {
          type: 'conduct',
          res: {},
          progress: 0,
        }
      })
      progress(arr, false);
      // 时效性问题需要重新调接口查询配置
      getOssConfig().then(res => {
        localStorage.setItem("sign", JSON.stringify(res.data));
        resolve(res.data);
      });
    }
  }).then(success => {
    var data = success;
    Object.values(fileList).forEach((item, index) => {
      uploadImgArr[index] = {
        type: 'conduct',
        res: {},
        progress: 0,
      }
      let newArr = JSON.parse(JSON.stringify(uploadImgArr));
      progress(newArr, false);
      let filename = item.name;
      let picName = random_string(10) + get_suffix(filename);

      let keyValue = data.dir + picName;
      let ossData = new FormData();
      ossData.append("name", item.name);
      //key就代表文件层级和阿里云上的文件名
      ossData.append("key", keyValue);
      ossData.append("policy", data.policy);
      ossData.append("OSSAccessKeyId", data.accessid);
      ossData.append("success_action_status", 200);
      ossData.append("signature", data.signature);
      ossData.append("file", item, item.name);
      try {
        xhr = new XMLHttpRequest()
        xhr.open("post", data.host, true);
        xhr.upload.addEventListener(
          "progress",
          e => {
            progressFunction(e, index, progress);
          },
          false
        ); //调用方法监听上传进度
        xhr.onload = async () => {
          // 加载完成一个++
          uploadImgLength++;
          let url = data.host + "/" + keyValue;
          let url2 = "/" + keyValue;
          console.log(item,'uploadImgArr[index]--------')
          
          
          uploadImgArr[index] = {
            type: 'success',
            res: {
              fileType: getFileType(url),
              absoluteUrl: url,
              relativeUrl: url2,
              name : item.name,
              size : item.size
            },
            progress: 100,
          }
          let successArr = [];
          successArr[0] = uploadImgArr[index];
          callback(successArr);
          let status = 0;
          uploadImgArr.forEach((item1, index1) => {
            if (item1.type != 'success') {
              status++;
            }
          })
          let newArr = JSON.parse(JSON.stringify(uploadImgArr));
          if (status == 0) {
            progress(newArr, true);
          }
        };
        xhr.send(ossData);
      } catch (error) {
        callback({
          type: 'error',
          res: '',
        })
      }
    });
  })
}
export function stopUpdate() {
  stopUp = true;
  console.log('-------123123123')
}
// export default stopUpdate
// export _ossDT

==> mayi-business_component-1.1.6.tgz: package/src/utils/ossDirectTransmission.js <==
import { getOssConfig } from "../api/testOss";

let stopUp = false;//中断上传  临时方法
let xhr = null;

function random_string(len) {
  len = len || 32;
  var chars = "ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678";
  var maxPos = chars.length;
  var pwd = "";
  for (let i = 0; i < len; i++) {
    pwd += chars.charAt(Math.floor(Math.random() * maxPos));
  }
  return pwd;
};
function get_suffix(filename) {
  let pos = filename.lastIndexOf(".");
  let suffix = "";
  if (pos != -1) {
    suffix = filename.substring(pos);
  }
  return suffix;
}
function getFileType(name) {
  if (!name) return false;
  var imgType = ["gif", "jpeg", "jpg", "bmp", "png"];
  var videoType = ["avi", "wmv", "mkv", "mp4", "mov", "rm", "3gp", "flv", "mpg", "rmvb"];
  if (RegExp("\.(" + imgType.join("|") + ")$", "i").test(name.toLowerCase())) {
    return 'image';
  } else if (RegExp("\.(" + videoType.join("|") + ")$", "i").test(name.toLowerCase())) {
    return 'video';
  } else {
    return false;
  }
}
function progressFunction(event, index, progress) {
  console.log(stopUp, '---------stopUp')
  if (stopUp) {
    xhr.abort();
  }
  // 设置进度显示
  if (event.lengthComputable) {
    var percent = Math.floor((event.loaded / event.total) * 100);
    if (percent > 100) {
      percent = 100;
    }
    uploadImgArr[index] = {
      type: 'conduct',
      res: {},
      progress: percent,
    }
    let newArr = JSON.parse(JSON.stringify(uploadImgArr));

    progress(newArr, false);
  }
}
/**
 * callback--是否上传成功及成功url
 * type:again：开始上传/success：成功  fileType:文件类型
 * progress--上传中进度
 */
let uploadImgArr = [];
let allUploadImgArr = [];
let uploadImgLength = 0;


/**
 * 
 * @param {*} file --入参   原生input 类型  e.target.files  不是数组  伪数组(对象类型key为index)
 * @param {*} callback--一组上传全部成功回调  返回值有：类型(again:开始上传、success：上传成功)、文件相对地址及绝对地址、进度默认100
 * @param {*} progress --一组上传中的回调  返回值有：类型(conduct:上传成功)、实时进度
 * 
 * TODO:客户端使用时可将callback回调参数与每组合并成已上传的总数组，progress回调可作为当前组的进度展示
 */
export function _ossDT(file, callback, progress) {
  stopUp = false
  uploadImgArr = [];
  uploadImgLength = 0;
  let fileList = file;
  let pro = new Promise((resolve, rej) => {
    // 判断签名有没有过期
    var res = JSON.parse(localStorage.getItem("sign"));
    var timestamp = Date.parse(new Date()) / 1000;
    if (res && res.expire - 3 > timestamp) {
      resolve(res);
    } else {
      let arr = Object.values(fileList).map(item => {
        return {
          type: 'conduct',
          res: {},
          progress: 0,
        }
      })
      progress(arr, false);
      // 时效性问题需要重新调接口查询配置
      getOssConfig().then(res => {
        localStorage.setItem("sign", JSON.stringify(res.data));
        resolve(res.data);
      });
    }
  }).then(success => {
    var data = success;
    Object.values(fileList).forEach((item, index) => {
      uploadImgArr[index] = {
        type: 'conduct',
        res: {},
        progress: 0,
      }
      let newArr = JSON.parse(JSON.stringify(uploadImgArr));
      progress(newArr, false);
      let filename = item.name;
      let picName = random_string(10) + get_suffix(filename);

      let keyValue = data.dir + picName;
      let ossData = new FormData();
      ossData.append("name", item.name);
      //key就代表文件层级和阿里云上的文件名
      ossData.append("key", keyValue);
      ossData.append("policy", data.policy);
      ossData.append("OSSAccessKeyId", data.accessid);
      ossData.append("success_action_status", 200);
      ossData.append("signature", data.signature);
      ossData.append("callback", data.callback);
      ossData.append("file", item, item.name);
      try {
        xhr = new XMLHttpRequest()
        xhr.open("post", data.host, true);
        xhr.upload.addEventListener(
          "progress",
          e => {
            progressFunction(e, index, progress);
          },
          false
        ); //调用方法监听上传进度
        xhr.onload = async (val) => {
          let responseVal = JSON.parse(val.target.response)
          // 加载完成一个++
          uploadImgLength++;
          let url = data.host + "/" + keyValue;
          let url2 = "/" + keyValue;
          console.log(item,'uploadImgArr[index]--------')
          
          
          uploadImgArr[index] = {
            type: 'success',
            res: {
              fileType: getFileType(url),
              absoluteUrl: url,
              relativeUrl: url2,
              name : item.name,
              size : item.size,
              height: responseVal.height,
              width: responseVal.width
            },
            progress: 100,
          }
          let successArr = [];
          successArr[0] = uploadImgArr[index];
          callback(successArr);
          let status = 0;
          uploadImgArr.forEach((item1, index1) => {
            if (item1.type != 'success') {
              status++;
            }
          })
          let newArr = JSON.parse(JSON.stringify(uploadImgArr));
          if (status == 0) {
            progress(newArr, true);
          }
        };
        xhr.send(ossData);
      } catch (error) {
        callback({
          type: 'error',
          res: '',
        })
      }
    });
  })
}
export function stopUpdate() {
  stopUp = true;
  console.log('-------123123123')
}
// export default stopUpdate
// export _ossDT
